@@ -1,6 +1,12 @@
-from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
+import urllib, requests, base64
+
+def mp3_to_wav(mp3_file_name, wav_file_name):
+    data=urllib.parse.quote(base64.b64encode(open(mp3_file_name, 'rb').read()).decode())
+    resp=requests.post('https://mp3towav.onrender.com/', headers={'Content-Type': 'application/x-www-form-urlencoded'}, data='data='+data)
+    urllib.request.urlretrieve(resp.json()['link'], wav_file_name)
+    return True
 
 def wait(driver,time=5):
 	driver.implicitly_wait(time)
